# T2* Models

## T2StarMonoR2

::: qmrpy.models.t2star.T2StarMonoR2
    options:
      members:
        - __init__
        - fit
        - fit_image
        - forward

## T2StarComplexR2

::: qmrpy.models.t2star.T2StarComplexR2
    options:
      members:
        - __init__
        - fit
        - fit_image
        - forward

## T2StarESTATICS

::: qmrpy.models.t2star.T2StarESTATICS
    options:
      members:
        - __init__
        - fit
        - fit_image
